@@ -39,7 +39,7 @@ class BroadcastThread(Thread):
 
 class GSPeerConnectionBroadcasterPiCaller:
     def __init__(self, gsdbs, camera, oncommand=None, setChannel=None):
-        self.sio = socketio.Client()
+        self.sio = socketio.AsyncClient()
         self.gsdbs = gsdbs
         self.camera = camera
         self._logger = logging.getLogger(__name__)
@@ -407,6 +407,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         else:
             connectURL = self.gsdbs.credentials["signalserver"]
 
-        self.sio.connect(
+        await self.sio.connect(
             f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}')
-        self.sio.wait()
+        await self.sio.wait()
